#!/bin/sh

# ADR3.sh
# Grep/plot asteroid colours (spectra) from the SDSS MOC catalogue.
# Miroslav Broz (miroslav.broz@email.cz), May 25th 2008

# Write a list of AstOrb-like files here:
FILES="r32_librating.astorb"

# This LONG listing have to be done only once:
#./sloan_astdys_lines.awk < ADR3.dat > ADR3.dat_lst
#./astorb_sort_astdys.sh ADR3.dat_lst > ADR3.dat_srt

for FILE in $FILES ; do

# for *family.list* files uncomment this line:
#  ./astorb_sort_astdys.sh $FILE > $FILE.srt							

# for OLD astorb format (r21.dat):
#  ./astorb2astdys_name.awk $FILE > $FILE.astdys; ./astorb_sort_astdys.sh $FILE.astdys > $FILE.srt

# for NEW *.astorb files:
  ./astorb2astdys_name6.awk $FILE > $FILE.astdys; ./astorb_sort_astdys.sh $FILE.astdys > $FILE.srt

# grep the ADR3 catalogue
  ./astdys_grep.awk $FILE.srt ADR3.dat_srt > $FILE.sloan_lines
  ./sloan_grep_lines.awk ADR3.dat $FILE.sloan_lines > $FILE.sloan

  ./sloan_astdys_colors.awk $FILE.sloan > $FILE.sloan_colors
  ./sloan_astdys_pc1pc2.awk $FILE.sloan > $FILE.sloan_pc1pc2

# catalogue vers. 3 with our PCA analysis
  ./sloan_astdys_pc1pc2_v3.awk $FILE.sloan > $FILE.sloan_pc1pc2_v3

# select only PC1/2 data with small magnitude errors
  awk '($3<0.1) && ($5<0.1)' < $FILE.sloan_pc1pc2 > $FILE.sloan_pc1pc2_lt0.1
  awk '($3<0.1) && ($5<0.1)' < $FILE.sloan_pc1pc2_v3 > $FILE.sloan_pc1pc2_v3_lt0.1

  ./sloan_astdys_pc1pc2_labels.awk < $FILE.sloan_pc1pc2_lt0.1
  mv sloan_astdys_pc1pc2_labels1.plt $FILE.sloan_pc1pc2_lt0.1.lab1
  mv sloan_astdys_pc1pc2_labels2.plt $FILE.sloan_pc1pc2_lt0.1.lab2

  wc -l $FILE.sloan_pc1pc2 $FILE.sloan_pc1pc2_lt0.1 > $FILE.sloan_pc1pc2.wc

# create a histogram of slopes
  awk '!/^#/{ print $2; }' $FILE.sloan_pc1pc2_lt0.1 > $FILE.sloan_pc1_lt0.1
  echo -e "20\n0 1\n$FILE.sloan_pc1_lt0.1" > hist.in
  ./hist3 < hist.in > $FILE.sloan_pc1_lt0.1_hist

#  ./$FILE.sloan_pc1_lt0.1_hist.plt

# normalized reflectance spectra
  ./sloan_spectra.awk $FILE.sloan > $FILE.sloan_spectra
  mv sloan_spectra.out.lab $FILE.sloan_spectra.lab
  mv sloan_spectra.out_good $FILE.sloan_spectra_good
  mv sloan_spectra.out_good.lab $FILE.sloan_spectra_good.lab
  mv sloan_spectra.out_mean $FILE.sloan_spectra_mean

#  ./$FILE.sloan_spectra.plt

done;

exit;


