#!/usr/bin/awk -f

BEGIN{
  print "# Principal components in the ADR3.dat (Sloan DSS MOC catalogue) <- multiple entries for one asteroid are possible!";
  print "# PC1 ~ spectral slope; PC2 ~ curvature caused by broad spectral features, like the 1 micron band";
  print "# astdys-like name & PC1 & PC1_err & PC2 & PC2_err & proper a & e & sin(i) & absolute magnitude H / mag";

# the solar analog:
  u_g_S = 1.32;
  g_r_S = 0.45;
  r_i_S = 0.10;
  i_z_S = 0.04;

  g_S = 0;	# an arbitrary constant (I will use differences anyway)
  u_S = u_g_S + g_S;
  r_S = g_S - g_r_S;
  i_S = r_S - r_i_S;
  z_S = i_S - i_z_S;

# principal components coefficients:
  a11 =  0.396; a12 = 0.553; a13 = 0.567; a14 = 0.465;
  a21 = -0.819; a22 = 0.017; a23 = 0.09 ; a24 = 0.567;

  OFMT=CONVFMT="%6.3f";
}
($34 == 1){
  if ($35 != 0) {
    dsg = $35;
  } else {
    dsg = gensub("_", "", 1, $36);
  }

  u = $20;
  g = $22;
  r = $24;
  i = $26;
  z = $28;
  uerr = $21;
  gerr = $23;
  rerr = $25;
  ierr = $27;
  zerr = $29;

  a_p = $58;
  e_p = $59;
  sini_p = $60;
  H = $47;

# subtract the solar analog (offset by a constant)
  u = u - u_S;
  g = g - g_S;
  r = r - r_S;
  i = i - i_S;
  z = z - z_S;

  PC1 =  a11*(u-g) + a12*(g-r) + a13*(g-i) + a14*(g-z);
  PC2 =  a21*(u-g) + a22*(g-r) + a23*(g-i) + a24*(g-z);

  PC1err =  sqrt( (a11*uerr)**2 + (a11*gerr)**2 + (a12*gerr)**2 + (a12*rerr)**2 + (a13*gerr)**2 + (a13*ierr)**2 + (a14*gerr)**2 + (a14*zerr)**2 );
  PC2err =  sqrt( (a21*uerr)**2 + (a21*gerr)**2 + (a22*gerr)**2 + (a22*rerr)**2 + (a23*gerr)**2 + (a23*ierr)**2 + (a24*gerr)**2 + (a24*zerr)**2 );

  print dsg "	" \
    PC1 "	" PC1err "	" \
    PC2 "	" PC2err "	" \
    a_p "	" e_p "	" sini_p "	" H;
}


